@@ -2,6 +2,7 @@
 local command = {}
 
 local fs = require("luarocks.fs")
+local dir = require("luarocks.dir")
 local cfg = require("luarocks.core.cfg")
 
 local unpack = table.unpack or unpack
@@ -24,21 +25,22 @@ function command.run_tests(test, args)
       test.script = "test.lua"
    end
 
+   if type(test.flags) == "table" then
+      -- insert any flags given in test.flags at the front of args
+      for i = 1, #test.flags do
+         table.insert(args, i, test.flags[i])
+      end
+   end
+
    local ok
 
    if test.script then
-      if type(test.script) ~= "string" then
-         return nil, "Malformed rockspec: 'script' expects a string"
-      end
       if not fs.exists(test.script) then
          return nil, "Test script " .. test.script .. " does not exist"
       end
-      local lua = fs.Q(cfg.variables["LUA"])  -- get lua interpreter configured
+      local lua = fs.Q(dir.path(cfg.variables["LUA_BINDIR"], cfg.lua_interpreter))  -- get lua interpreter configured
       ok = fs.execute(lua, test.script, unpack(args))
    elseif test.command then
-      if type(test.command) ~= "string" then
-         return nil, "Malformed rockspec: 'command' expects a string"
-      end
       ok = fs.execute(test.command, unpack(args))
    end
 
